# Changelog

## 1.1.0 (2025-06-28)

Full Changelog: [v1.0.1...v1.1.0](https://github.com/victorgabrieldeon/fv-api/compare/v1.0.1...v1.1.0)

### Features

* **client:** add support for aiohttp ([3534a3e](https://github.com/victorgabrieldeon/fv-api/commit/3534a3eecbed1108a21f11f798748b280e4210cc))


### Bug Fixes

* **ci:** release-doctor — report correct token name ([f70ee3e](https://github.com/victorgabrieldeon/fv-api/commit/f70ee3ea64a17500b2108224f81adc16af371833))
* **tests:** fix: tests which call HTTP endpoints directly with the example parameters ([89cd780](https://github.com/victorgabrieldeon/fv-api/commit/89cd780492fb7b46aa533b0f46ac132a61726d9f))


### Chores

* **ci:** only run for pushes and fork pull requests ([73594cb](https://github.com/victorgabrieldeon/fv-api/commit/73594cb0dd8113bab6b1e7b69c3013d4f189dbde))
* **readme:** update badges ([0a47345](https://github.com/victorgabrieldeon/fv-api/commit/0a47345d59a7d2890b11b5da490ff334e54dce3f))
* **tests:** skip some failing tests on the latest python versions ([94cd14f](https://github.com/victorgabrieldeon/fv-api/commit/94cd14feb2c7f6b1cc0ee01648837c4355849d0b))


### Documentation

* **client:** fix httpx.Timeout documentation reference ([ba8dd19](https://github.com/victorgabrieldeon/fv-api/commit/ba8dd19ada354aada7ab12e5c03d203c43ef0b3a))

## 1.0.1 (2025-06-17)

Full Changelog: [v1.0.0...v1.0.1](https://github.com/victorgabrieldeon/fv-api/compare/v1.0.0...v1.0.1)

### Chores

* **internal:** version bump ([96ef2d8](https://github.com/victorgabrieldeon/fv-api/commit/96ef2d83cecf6be5c5baaa8fc8e92ff5f9f12d66))

## 1.0.0 (2025-06-17)

Full Changelog: [v0.0.1-alpha.0...v1.0.0](https://github.com/victorgabrieldeon/fv-api/compare/v0.0.1-alpha.0...v1.0.0)

### Chores

* update SDK settings ([d32a8e0](https://github.com/victorgabrieldeon/fv-api/commit/d32a8e06890e7675ef95f80e8f51bcd4a74a3285))
* update SDK settings ([125f1a7](https://github.com/victorgabrieldeon/fv-api/commit/125f1a7cb1889b650ff268bf5c5fc26484757226))
